#
# spec file for package wyrmgus
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wyrmgus
Version:        3.5.4
Release:        bp155.2.11
Summary:        Game engine for Wyrmsun
License:        GPL-2.0-only
Group:          Amusements/Games/Strategy/Real Time
URL:            https://andrettin.github.io/
Source:         https://github.com/Andrettin/Wyrmgus/archive/v%{version}/Wyrmgus-%{version}.tar.gz
Patch0:         wyrmgus-fix-build.patch
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  lua51-devel
BuildRequires:  oaml-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(physfs)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(theora)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} <= 1320
BuildRequires:  pkgconfig(tolua++)
%else
BuildRequires:  libtolua++-5_1-devel
%endif

%description
Modified Stratagus engine for Wyrmsun

%package devel
Summary:        Real-time strategy gaming engine development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
These are the development files for Wyrmsun which is based on the Stratagus engine.

%prep
%setup -q -n Wyrmgus-%{version}
%patch0 -p1

%build
%cmake \
  -DWITH_BZIP2=ON \
  -DWITH_PHYSFS=ON \
  -DGAMEDIR=%{_bindir} \
  -DENABLE_USEGAMEDIR=OFF
%make_jobs

%install
%cmake_install
install -D -m 0644 doc/stratagus.6 %{buildroot}%{_mandir}/man6/wyrmgus.6
install -D -m 0644 gameheaders/stratagus-game-launcher.h %{buildroot}%{_includedir}/wyrmgus-game-launcher.h
mv %{buildroot}%{_bindir}/stratagus %{buildroot}%{_bindir}/wyrmgus

%files
%license COPYING
%doc README.MD
%{_bindir}/wyrmgus
%{_mandir}/man6/wyrmgus.6%{?ext_man}

%files devel
%{_includedir}/wyrmgus-game-launcher.h

%changelog
* Sun Mar  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 3.5.4
  * Added data type base class for unit types, upgrades and etc.
  * Fixed issue which caused rally point map layers to be saved
    incorrectly.
  * Remove instances of \r from the config data strings
  * Added snow and ice flags, made the map field flags into an enum
  * Added comment to better explain the CPlayer::CanRecruitHero code
  * Improved the check to see if a file is in the user's home directory
  * Fixed issue which caused a crash when starting a second game
  * Fixed issue with quest failure
  * Improved worker automatic level-up upgrade choice
  * Potential fix for mouse jumping issues
  * Added support for certain spells being empowered in a particular plane
  * Fixed issue which caused building i.e. a road near a rock tile to
    recalculate the rock tile's transitions.
- Add patch:
  * wyrmgus-fix-build.patch
- Run spec-cleaner
- Use pkg-config style dependencies
* Sun Sep 10 2017 rpm@fthiessen.de
- Update to 2.8.1:
  * Added code for terrain features
  * Terrain features are groups of tiles which have their name
  displayed when one of the tiles is hovered over
  * Update to supply display
  * Fixed issue with the AI not building town halls close
  to silver and gold deposits
  * Ai force update
  * Added support for variation weight
  * Update to character code to make heroes be more dynamically
  applied to the scenario mode
  * Fixed issue with minecart stone right-click crash
  * Fixed issue with genversion
* Tue Feb  7 2017 mailaender@opensuse.org
- Update to version 2.5.3
* Tue Sep  6 2016 malcolmlewis@opensuse.org
- Update to version 2.4.2:
  + Removed species development system (should be replaced later
    with something that is lair-based).
- Changes from version 2.4.1:
  + Reduced the starting resources of split-off factions, as they
    were too strong.
* Sun Aug 21 2016 mailaender@opensuse.org
- Updated to version 2.4.0
- Removed fix-find-toluapp.patch
* Sun May 15 2016 rpm@fthiessen.de
- Updated to version 2.2.1
- Now using cmake macros
* Sat Jan 16 2016 rpm@fthiessen.de
- Fixed build on openSUSE > 13.2 after tolua++ package got renamed,
  therefore also modified fix-find-toluapp. patch.
* Sun Dec 27 2015 rpm@fthiessen.de
- Added fix-find-toluapp.patch to fix build on openSUSE > 13.2
* Thu Dec 24 2015 mailaender@opensuse.org
- update to version 1.8.6
* Sat Dec 19 2015 mailaender@opensuse.org
- initial packaging
